@@ -1,10 +1,10 @@
+# pylint: disable=bad-continuation,protected-access
 from __future__ import unicode_literals
 
 import ast
 import collections
-from cached_property import cached_property
 
-# pylint: disable=bad-continuation,protected-access
+from cached_property import cached_property
 
 
 def namedtuple_lower(t):
@@ -93,15 +93,6 @@ def _from_import_module(ast_import):
     )
 
 
-def _check_only_one_name(ast_import):
-    if len(ast_import.names) != 1:
-        raise AssertionError(
-            'Cannot construct import with multiple names: {0!r}'.format(
-                ast_import,
-            )
-        )
-
-
 class ImportImportSortKey(collections.namedtuple(
     'ImportImportSortKey', ['module', 'asname'],
 )):
@@ -109,7 +100,6 @@ class ImportImportSortKey(collections.namedtuple(
 
     @classmethod
     def from_python_ast(cls, ast_import):
-        _check_only_one_name(ast_import)
         return cls(ast_import.names[0].name, ast_import.names[0].asname or '')
 
 
@@ -120,7 +110,6 @@ class FromImportSortKey(collections.namedtuple(
 
     @classmethod
     def from_python_ast(cls, ast_import):
-        _check_only_one_name(ast_import)
         return cls(
             _from_import_module(ast_import),
             ast_import.names[0].name,
@@ -135,8 +124,12 @@ def _ast_alias_to_s(ast_alias):
         return ast_alias.name
 
 
-def _format_import_import(ast_alias):
-    return 'import {0}\n'.format(_ast_alias_to_s(ast_alias))
+def _format_import_import(ast_aliases):
+    return 'import {0}\n'.format(
+        ', '.join(
+            sorted(_ast_alias_to_s(ast_alias) for ast_alias in ast_aliases)
+        ),
+    )
 
 
 class ImportImport(AbstractImportObj):
@@ -145,18 +138,21 @@ class ImportImport(AbstractImportObj):
 
     def split_imports(self):
         return [
-            type(self).from_str(_format_import_import(ast_alias))
+            type(self).from_str(_format_import_import([ast_alias]))
             for ast_alias in self.ast_obj.names
         ]
 
     def to_text(self):
-        if self.has_multiple_imports:
-            raise AssertionError('Cannot format multiple imports')
-        return _format_import_import(self.ast_obj.names[0])
+        return _format_import_import(self.ast_obj.names)
 
 
-def _format_from_import(module, ast_alias):
-    return 'from {0} import {1}\n'.format(module, _ast_alias_to_s(ast_alias))
+def _format_from_import(module, ast_aliases):
+    return 'from {0} import {1}\n'.format(
+        module,
+        ', '.join(
+            sorted(_ast_alias_to_s(ast_alias) for ast_alias in ast_aliases)
+        ),
+    )
 
 
 class FromImport(AbstractImportObj):
@@ -166,16 +162,14 @@ class FromImport(AbstractImportObj):
     def split_imports(self):
         return [
             type(self).from_str(_format_from_import(
-                self.ast_obj.module, ast_alias,
+                self.ast_obj.module, [ast_alias],
             ))
             for ast_alias in self.ast_obj.names
         ]
 
     def to_text(self):
-        if self.has_multiple_imports:
-            raise AssertionError('Cannot format multiple imports')
         return _format_from_import(
-            _from_import_module(self.ast_obj), self.ast_obj.names[0],
+            _from_import_module(self.ast_obj), self.ast_obj.names,
         )
 
 
